@@ -3,7 +3,7 @@ import sys as _sys
 import random as _random
 
 grad_precision_bit = 32
-grad_file_ext = '.npy'  # numpy
+grad_file_ext = '.npy'
 
 grads_file = f'grads{grad_file_ext}'
 avg_grads_file = f'avg_grads{grad_file_ext}'
